@@ -92,6 +92,7 @@ class Receiver:
         self._core_commands: Dict[str, str] = dict(
             source_asdf="source ~/.asdf/asdf.sh",
             ember_release="ember release",
+            ember_release_all_yes="ember release --yes",
             git_change_branch_master="git checkout master",
             git_change_branch_develop="git checkout develop",
             git_fetch_all="git fetch --all",
@@ -280,7 +281,7 @@ class Receiver:
                 self._core_commands["git_change_branch_master"],
                 self._core_commands["git_pull_origin_master"],
                 self._core_commands["git_fetch_all"],
-                self._core_commands["ember_release"],
+                self._core_commands["ember_release_all_yes"],
                 self._npm_auto_release_commands["npm_set_parasut_registry"],
                 self._npm_auto_release_commands["npm_login"],
                 self._npm_auto_release_commands["npm_publish"],
@@ -326,7 +327,7 @@ class Receiver:
                 self._core_commands["git_change_branch_develop"],
                 self._core_commands["git_pull_origin_develop"],
                 self._core_commands["git_fetch_all"],
-                self._core_commands["ember_release"],
+                self._core_commands["ember_release_all_yes"],
                 self._npm_auto_release_commands["npm_set_parasut_registry"],
                 self._npm_auto_release_commands["npm_login"],
                 self._npm_auto_release_commands["npm_publish"],
